Function amazon_sp_orders::apis::shipment_api::update_shipment_status
source · [−]pub async fn update_shipment_status(
configuration: &Configuration,
order_id: &str,
payload: UpdateShipmentStatusRequest
) -> Result<(), Error>Expand description
Update the shipment status for an order that you specify. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 5 | 15 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values then those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.